Home

- Home
- Setup
- Program
- Manage
- Logout

Time | Today | Sat | Sun | Mon
01:28 AM | 75 - 72° | 80 - 73° | 85 - 73° | 85 - 74°

Online
Valve Unit:
Online
0
0
0
0

## Zone | 2 - Backyard Zone2 | 3 - Trees Fence | 4 - Backyard Zone1

## Manual |  |  |  |

## Auto |  |  |  |
### Edit |  |  |  |
### Rain Delay |  |  |  |
### Next Cycle | Delayed | Off | Off | Off

Copyright © 2016 Melnor, Inc. All Rights Reserved. Forecast by OpenWeatherMap